# Generated by Codex on 2026-02-23

# Django
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("discord_obfuscate", "0005_role_ordering"),
    ]

    operations = [
        migrations.AlterField(
            model_name="discordroleorderconfig",
            name="reorder_mode",
            field=models.CharField(
                choices=[
                    ("desired", "Reorder to desired configuration at next reorder task"),
                    ("shuffle", "Randomly reorganize unlocked roles"),
                ],
                default="shuffle",
                help_text="Controls how unlocked roles are positioned during the reorder task.",
                max_length=16,
            ),
        ),
    ]
