# Generated by Discord Obfuscate on 2026-02-20

# Django
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("discord_obfuscate", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="discordobfuscateconfig",
            name="random_key_reposition_enabled",
            field=models.BooleanField(
                default=True,
                help_text="Enable automatic role repositioning during random key rotation.",
            ),
        ),
    ]
