# Generated by Discord Obfuscate on 2026-02-20

# Django
from django.db import migrations, models
import django.core.validators


class Migration(migrations.Migration):
    dependencies = [
        ("discord_obfuscate", "0002_random_key_reposition_enabled"),
    ]

    operations = [
        migrations.AddField(
            model_name="discordobfuscateconfig",
            name="random_key_reposition_min_position",
            field=models.PositiveIntegerField(
                default=1,
                help_text=(
                    "Lowest position for random-key role repositioning. "
                    "1 is just above @everyone. Must leave enough space below position 250."
                ),
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(249),
                ],
            ),
        ),
        migrations.AddField(
            model_name="discordobfuscateconfig",
            name="require_existing_role",
            field=models.BooleanField(
                default=True,
                help_text=(
                    "Only use roles that already exist in Discord. "
                    "When enabled, Alliance Auth will not be able to create new roles; "
                    "missing roles must be created manually on the Discord server."
                ),
            ),
        ),
    ]
